summaryrefslogtreecommitdiff
path: root/src/gc/env/gcenv.os.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gc/env/gcenv.os.h')
-rw-r--r--src/gc/env/gcenv.os.h7
1 files changed, 2 insertions, 5 deletions
diff --git a/src/gc/env/gcenv.os.h b/src/gc/env/gcenv.os.h
index 1707f0dabe..41e46f8f0f 100644
--- a/src/gc/env/gcenv.os.h
+++ b/src/gc/env/gcenv.os.h
@@ -282,16 +282,13 @@ public:
// Processor topology
//
- // Get number of logical processors
- static uint32_t GetLogicalCpuCount();
-
- // Get size of the largest cache on the processor die
+ // Get size of the on die cache per logical processor
// Parameters:
// trueSize - true to return true cache size, false to return scaled up size based on
// the processor architecture
// Return:
// Size of the cache
- static size_t GetLargestOnDieCacheSize(bool trueSize = true);
+ static size_t GetCacheSizePerLogicalCpu(bool trueSize = true);
// Get number of processors assigned to the current process
// Return: